@@ -14,9 +14,11 @@ Exports:
 
 *  ``ExitState`` class
 *  ``main`` function
+*  ``publish_flow_main`` function
 *  ``release_flow_main`` function
 """
 
+from ._publish_flow import publish_flow_main  # noqa: F401
 from ._release_flow import release_flow_main  # noqa: F401
 from .build_harness_group import main  # noqa: F401
 from .state import ExitState  # noqa: F401
