@@ -16,10 +16,10 @@ import traceback
 import typing
 
 import click
+from click_logging_config import LoggingConfiguration, logging_parameters
 
-from build_harness._logging import LoggingState
 from build_harness._utility import report_console_error
-from build_harness._version import acquire_version
+from build_harness._version import __version__, acquire_version
 from build_harness.tools.git import (
     DEFAULT_DEFAULT_BRANCH_NAME,
     GitNotFoundError,
@@ -30,7 +30,7 @@ from build_harness.tools.git import (
 
 from ._declarations import (
     DEFAULT_CONSOLE_LOGGING_ENABLED,
-    DEFAULT_FILE_LOGGING_DISABLED,
+    DEFAULT_FILE_LOGGING_ENABLED,
     DEFAULT_PROJECT_PATH,
 )
 from ._release_id import InvalidReleaseId, validate_release_id
@@ -38,6 +38,15 @@ from .state import CommandState, ExitState
 
 log = logging.getLogger(__name__)
 
+DEFAULT_RELEASEFLOW_LOGCONFIG = LoggingConfiguration.parse_obj(
+    {
+        "enable_file_logging": DEFAULT_FILE_LOGGING_ENABLED,
+        "enable_console_logging": DEFAULT_CONSOLE_LOGGING_ENABLED,
+        "file_logging": {"log_file_path": pathlib.Path("release_flow.log")},
+        "log_level": "debug",
+    }
+)
+
 
 @click.command()
 @click.version_option(version=acquire_version())
@@ -61,6 +70,7 @@ log = logging.getLogger(__name__)
     show_default=True,
     type=str,
 )
+@logging_parameters(DEFAULT_RELEASEFLOW_LOGCONFIG)
 def release_flow_main(
     default_branch: str, git: typing.Optional[str], project: str
 ) -> None:
@@ -81,16 +91,11 @@ def release_flow_main(
     the count method is always the same.
     """
     try:
-        logging_state = LoggingState(
-            disable_file_logging=DEFAULT_FILE_LOGGING_DISABLED,
-            enable_console_logging=DEFAULT_CONSOLE_LOGGING_ENABLED,
-            log_level_text="debug",
-        )
         state = CommandState(
-            logging_state=logging_state,
             project_path=pathlib.Path(project),
             venv_path=pathlib.Path(sys.argv[0]).parent.absolute(),
         )
+        log.info(f"build harness version, {__version__}")
 
         validate_git(git)
 
