@@ -13,14 +13,11 @@ import dataclasses
 import enum
 import pathlib
 
-from build_harness._logging import LoggingState
-
 
 @dataclasses.dataclass
 class CommandState:
     """Global click command state context."""
 
-    logging_state: LoggingState
     project_path: pathlib.Path
     venv_path: pathlib.Path
 
