@@ -17,7 +17,9 @@ from build_harness._version import DEFAULT_RELEASE_ID, acquire_version
 def test_clean(mocker):
     mock_here = mocker.create_autospec(pathlib.Path)
 
-    mocker.patch("build_harness._version.pathlib.Path.absolute", return_value=mock_here)
+    mocker.patch(
+        "build_harness._version.pathlib.Path.absolute", return_value=mock_here
+    )
     mock_here.is_file.return_value = True
 
     mock_handle = mock_here.open.return_value.__enter__.return_value
@@ -31,7 +33,9 @@ def test_clean(mocker):
 def test_missing_file(mocker):
     mock_here = mocker.create_autospec(pathlib.Path)
 
-    mocker.patch("build_harness._version.pathlib.Path.absolute", return_value=mock_here)
+    mocker.patch(
+        "build_harness._version.pathlib.Path.absolute", return_value=mock_here
+    )
     mock_here.is_file.return_value = False
 
     result = acquire_version()
@@ -42,7 +46,9 @@ def test_missing_file(mocker):
 def test_empty_file(mocker):
     mock_here = mocker.create_autospec(pathlib.Path)
 
-    mocker.patch("build_harness._version.pathlib.Path.absolute", return_value=mock_here)
+    mocker.patch(
+        "build_harness._version.pathlib.Path.absolute", return_value=mock_here
+    )
     mock_here.is_file.return_value = True
 
     mock_handle = mock_here.open.return_value.__enter__.return_value
